@@ -163,9 +163,6 @@ sub prepare {
 		get_regions($self->{filename}, $text, $_);
 	    } @{$self->{block}};
 	}
-	elsif ($self->{all} or $self->{only}) {	# --all, --only-matching
-	    ( [ 0, length ] );
-	}
 	elsif (@blocks) {			# from matched range
 	    my %opt = ( A => $self->{after},
 		        B => $self->{before},
@@ -258,16 +255,13 @@ sub compose {
 	$self->{MATCHED} += @matched;
 	if ($self->{only}) {
 	    push @list, map({ [ $_, $_ ] } @matched);
+	} elsif ($self->{all}) {
+	    push @list, [ [ 0, length ] ] if @list == 0;
+	    push @{$list[0]}, @matched;
 	} else {
 	    push @list, [ $bp->[$bi], @matched ];
 	}
     }
-    ##
-    ## in the case --all and --block both specified
-    ##
-    if ($self->{all} and @list > 1) {
-	@list = ( [ [ 0, length ], map { shift @$_; @$_ } @list ] );
-    }
 
     ##
     ## ( [ [blockstart, blockend], [start, end], [start, end], ... ],
